==> v0.3.1.tar.gz: front-utils/src/Business/lu-webapi-crud-business.js <==
/**
 * Created by robin on 12/11/16.
 */

(function () {
    'use strict';
    angular.module('luticate2Utils')
        .factory('luWebApiCrudBusiness', ['luBusiness', '$q', function (luBusiness, $q) {

            var luWebApiCrudBusiness = {};

            luWebApiCrudBusiness.create = function (dataAccess) {
                var Business = luBusiness.create();

                Business.dataAccess = dataAccess;

                Business.dboInitializer = Business.dataAccess.dboInitializer;

                Business.initDbo = function(dbo)
                {
                    return Business.dataAccess.dboInitializer.initDbo(dbo, Business.dataAccess.TYPE_DBO);
                };

                Business.initListDbo = function(list)
                {
                    return Business.dataAccess.dboInitializer.initListDbo(list, Business.dataAccess.TYPE_DBO);
                };

                Business.initPaginatedDbo = function(data)
                {
                    return Business.dataAccess.dboInitializer.initPaginatedDbo(data, Business.dataAccess.TYPE_DBO);
                };

                Business.thenInitDbo = function(promise)
                {
                    return Business.dataAccess.dboInitializer.thenInitDbo(promise, Business.dataAccess.TYPE_DBO);
                };

                Business.thenInitListDbo = function(promise)
                {
                    return Business.dataAccess.dboInitializer.thenInitListDbo(promise, Business.dataAccess.TYPE_DBO);
                };

                Business.thenInitPaginatedDbo = function(promise)
                {
                    return Business.dataAccess.dboInitializer.thenInitPaginatedDbo(promise, Business.dataAccess.TYPE_DBO);
                };



                Business.getSingleById = function (id, luBusyGroups) {
                    return Business.dataAccess.getSingleById(id, luBusyGroups);
                };

                Business.getMultiple = function (orderBy, filter, page, perPage, luBusyGroups) {
                    return Business.dataAccess.getMultiple(orderBy, filter, page, perPage, luBusyGroups);
                };

                Business.getMultipleToList = function (orderBy, filter, page, perPage, luBusyGroups) {
                    var deferred = $q.defer();
                    Business.getMultiple(orderBy, filter, page, perPage, luBusyGroups).then(function(data)
                    {
                        deferred.resolve(data.data);
                    }, deferred.reject);
                    return deferred.promise;
                };

                Business.addDbo = function(data, luBusyGroups) {
                    return Business.dataAccess.addDbo(data, luBusyGroups);
                };

                Business.editSingleByIdDbo = function(id, data, luBusyGroups) {
                    return Business.dataAccess.editSingleByIdDbo(id, data, luBusyGroups);
                };

                Business.deleteDbo = function(id, luBusyGroups) {
                    return Business.dataAccess.deleteDbo(id, luBusyGroups);
                };

                return Business;
            };

            return luWebApiCrudBusiness;

        }]);
})();

==> v0.5.0.tar.gz: front-utils/src/Business/lu-webapi-crud-business.js <==
/**
 * Created by robin on 12/11/16.
 */

(function () {
    'use strict';
    angular.module('luticate2Utils')
        .factory('luWebApiCrudBusiness', ['luBusiness', '$q', function (luBusiness, $q) {

            var luWebApiCrudBusiness = {};

            luWebApiCrudBusiness.create = function (dataAccess) {
                var Business = luBusiness.create();

                Business.dataAccess = dataAccess;

                Business.dboInitializer = Business.dataAccess.dboInitializer;

                Business.initDbo = function(dbo)
                {
                    return Business.dataAccess.dboInitializer.initData(dbo, Business.dataAccess.TYPE_DBO);
                };

                Business.initListDbo = function(list)
                {
                    return Business.dataAccess.dboInitializer.initListData(list, Business.dataAccess.TYPE_DBO);
                };

                Business.initPaginatedDbo = function(data)
                {
                    return Business.dataAccess.dboInitializer.initPaginatedData(data, Business.dataAccess.TYPE_DBO);
                };

                Business.thenInitDbo = function(promise)
                {
                    return Business.dataAccess.dboInitializer.thenInitData(promise, Business.dataAccess.TYPE_DBO);
                };

                Business.thenInitListDbo = function(promise)
                {
                    return Business.dataAccess.dboInitializer.thenInitListData(promise, Business.dataAccess.TYPE_DBO);
                };

                Business.thenInitPaginatedDbo = function(promise)
                {
                    return Business.dataAccess.dboInitializer.thenInitPaginatedData(promise, Business.dataAccess.TYPE_DBO);
                };



                Business.getSingleById = function (id, luBusyGroups) {
                    return Business.dataAccess.getSingleById(id, luBusyGroups);
                };

                Business.getMultiple = function (orderBy, filter, page, perPage, luBusyGroups) {
                    return Business.dataAccess.getMultiple(orderBy, filter, page, perPage, luBusyGroups);
                };

                Business.getMultipleToList = function (orderBy, filter, page, perPage, luBusyGroups) {
                    var deferred = $q.defer();
                    Business.getMultiple(orderBy, filter, page, perPage, luBusyGroups).then(function(data)
                    {
                        deferred.resolve(data.data);
                    }, deferred.reject);
                    return deferred.promise;
                };

                Business.addDbo = function(data, luBusyGroups) {
                    return Business.dataAccess.addDbo(data, luBusyGroups);
                };

                Business.editSingleByIdDbo = function(id, data, luBusyGroups) {
                    return Business.dataAccess.editSingleByIdDbo(id, data, luBusyGroups);
                };

                Business.deleteDbo = function(id, luBusyGroups) {
                    return Business.dataAccess.deleteDbo(id, luBusyGroups);
                };

                return Business;
            };

            return luWebApiCrudBusiness;

        }]);
})();
